<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Podľa predvolených nastavení všetky odkazy k obrázkom (s typom v parametre, ktorý uvádza mime/typ obrázka) a odkazy v triede <code>.mediabox</code> obohacuje multimediálny box.

Každý odkaz môžete osobitne nastaviť pomocou doplnkových tried:

-* <code>boxIframe</code> umožňuje otvárať odkaz v ráme iframe,

-* <code>boxWidth-350px</code> umožňuje definovať šírku poľa 350px,

-* <code>boxHeight-90pc</code> umožňuje zadať výšku poľa 90%.

Ovládací panel vám umožňuje všeobecné nastavenia podľa vašich želaní vybrať dizajn boxu z dostupných vzhľadov.

Tento zásuvný modul spolupracuje so šablónami, ktoré obsahujú tag <code>#INSERT_HEAD</code>',
	'mediabox_nom' => 'Multimediálny box',
	'mediabox_slogan' => 'Multimediálny box',
];
